# Copyright (c) 2015 Ultimaker B.V.
# Cura is released under the terms of the LGPLv3 or higher.

CuraVersion = "3.4.1"
CuraBuildType = ""
CuraDebugMode = True if "" == "ON" else False
CuraSDKVersion = ""
CuraCloudAPIRoot = ""
CuraCloudAPIVersion = ""
